/*

  Universal 8bit Graphics Library, https://github.com/olikraus/u8glib/
  
  Copyright (c) 2011, olikraus@gmail.com
  All rights reserved.

  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:

  * Redistributions of source code must retain the above copyright notice, this list 
    of conditions and the following disclaimer.
    
  * Redistributions in binary form must reproduce the above copyright notice, this 
    list of conditions and the following disclaimer in the documentation and/or other 
    materials provided with the distribution.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND 
  CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, 
  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR 
  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
  STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.  
  
*/


#include "U8glib.h"

// This is for the SSD1306 128x64 controller using the 4-wire SPI protocol
#define D0 8     // SCL (SCK)
#define D1 9     // MOSI
#define RES 10   // 
#define DC  11   // A0
#define CS 12    // CS (don't need this - just connect CS to GND
U8GLIB_SSD1306_128X64 u8g(D0, D1, CS, DC, RES);

const uint8_t rook_bitmap[] PROGMEM = {
  0x00,         // 00000000 
  0x55,         // 01010101
  0x7f,          // 01111111
  0x3e,         // 00111110
  0x3e,         // 00111110 
  0x3e,         // 00111110
  0x3e,         // 00111110 
  0x7f           // 01111111
};


void draw(int i) {
  // graphic commands to redraw the complete screen should be placed here
  switch(i) {
  case 0:
    u8g.drawPixel(0,0);
    u8g.drawPixel(0,63);
    u8g.drawPixel(127,0);
    u8g.drawPixel(127,63);
    break;
  case 1:
    u8g.drawVLine(20,0,32);
    u8g.drawLine(0,64/2,127,64/2);
    break;
  case 2:
    u8g.drawFrame(30, 5, 50, 40);
    u8g.drawBox(50, 25, 50, 40);
    break;
  case 3:
    u8g.drawCircle(127/2, 64/2, 25);
    u8g.drawDisc(90, 44, 15);
    break;
  case 4: 
    u8g.drawBitmapP(64, 32, 1, 8, rook_bitmap);
    break;
  case 5:
    u8g.setFont(u8g_font_4x6);
    u8g.drawStr(12, 6, "Hello world");
    u8g.setFont(u8g_font_5x8);
    u8g.drawStr(12, 18, "Hello world");
    u8g.setFont(u8g_font_6x10);
    u8g.drawStr(12, 31, "Hello world");
    u8g.setFont(u8g_font_7x13);
    u8g.drawStr(12, 46, "Hello world");
    u8g.setFont(u8g_font_9x15);
    u8g.drawStr(12, 63, "Hello world");
    break;
  case 6:
    u8g.setFont(u8g_font_7x13);
    u8g.drawStr(0, 9, "Top");
    u8g.drawStr90(118, 0, "Right");
    u8g.drawStr180(128, 54, "Bottom");
    u8g.drawStr270(10, 63, "Left");
    break;
  
  }
}

void setup() {
}

void loop() {
  // picture loop
  static int i=0;
  u8g.firstPage();  
  do {
    draw(i);
  } while( u8g.nextPage() );

  i++;
  if (i > 6) i=0;
  // rebuild the picture after some delay
  delay(2000);
}

