// Displays an analog and a digital clock

// This is for the SSD1306 128x64 controller using the 4-wire SPI protocol
#include "U8glib.h"
#define D0 8     // SCL (SCK)
#define D1 9     // MOSI
#define RES 10   // 
#define DC  11   // A0
#define CS 12    // CS (don't need this - just connect CS to GND
U8GLIB_SSD1306_128X64 u8g(D0, D1, CS, DC, RES);

const byte clockCenterX = 31;
const byte clockCenterY = 32;

int year;
int month;
int date;
int day;
int hour;
int minute;
int second;

void setTime() {
  year = 2017;
  month = 5;
  date = 26;
  day = 6;
  hour = 7;
  minute = 13;
  second = 52;
}

void getTime() {
  second++;
  if (second == 60) {
    second = 0;
    minute++;
  }
  if (minute == 60) {
    minute = 0;
    hour++;
  }
  if (hour == 24) {
    hour = 0;
    date++;
    day++;
  }
}

void drawHand(float rotation, float ratio, int radius) {
  float angle = 0;
  int X2 = 0;
  int Y2 = 0;
  angle = (rotation-15) * 2.0 * 3.1415 / ratio;
  X2 = clockCenterX + radius * cos(angle);
  Y2 = clockCenterY + radius * sin(angle);
  u8g.drawLine(clockCenterX, clockCenterY, X2, Y2);
}

void drawClockFace() { // draw the clock face
  float angle = 0;
  int X2 = 0;
  int Y2 = 0;
  int X3 = 0;
  int Y3 = 0;
  u8g.drawCircle(clockCenterX, clockCenterY, 31);  // circle around the dial
  u8g.drawDisc(clockCenterX, clockCenterY, 2);

  u8g.setFont(u8g_font_04b_03b);  // small size figures on dial
  u8g.setFontPosTop();
  u8g.drawStr(28, 5, "12");
  u8g.drawStr(54, 29, "3");
  u8g.drawStr(31, 52, "6");
  u8g.drawStr(7, 29, "9");

  for(int dash = 0; dash<12; dash++) { // draw the "5 minute" dashes
    angle = dash / 12.0 * 2 * 3.1415;
    X2 = clockCenterX + 30 * cos(angle);
    Y2 = clockCenterY + 30 * sin(angle);
    X3 = clockCenterX + 28 * cos(angle);
    Y3 = clockCenterY + 28 * sin(angle);
    u8g.drawLine(X2, Y2, X3, Y3);
  }
}

void draw() {
  //u8g.drawXBMP( 103, 10, 32, 32, ico_bitmap_temp);
  //u8g.setFont(u8g_font_04b_03);
  // draw analog clock
  drawClockFace();
  
  drawHand(hour, 12, 15);     // rotation, rotationsteps, length
  drawHand(minute, 60, 21);   // rotation, rotationsteps, length
  drawHand(second, 60, 27);   // rotation, rotationsteps, length

  // draw digital clock
  //u8g.setFont(u8g_font_orgv01r);
  
  u8g.setFont(u8g_font_6x10);
  u8g.setPrintPos(65, 12);
  if (hour < 10) u8g.print("0");
  u8g.print(hour);
  u8g.print(":");
  if (minute < 10) u8g.print("0");
  u8g.print(minute);
  u8g.print(":");
  if (second < 10) u8g.print("0");
  u8g.print(second);
  u8g.setFont(u8g_font_5x8);
  u8g.print(" am");
  
  u8g.setFont(u8g_font_6x10);
  u8g.setPrintPos(72, 36);
  u8g.print("Friday");
  
  u8g.setFont(u8g_font_7x13);
  u8g.setPrintPos(59, 63);
  if (month < 10) u8g.print("0");
  u8g.print(month);
  u8g.print("/");
  if (date < 10) u8g.print("0");
  u8g.print(date);
  u8g.print("/");
  u8g.print(year);
}

void setup() {
  setTime();
}

void loop(){
   // picture loop
  u8g.firstPage();  
  do {
    draw();
  } while( u8g.nextPage() );
  
  // rebuild the picture after some delay
  delay(1000);
  getTime();

}
